==> reahl-doc-2.0.1.tar.gz: reahl-doc-2.0.1/doc/Tutorial.mm <==
<map version="0.9.0">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node CREATED="1354018227940" ID="ID_486696790" MODIFIED="1354018280646" TEXT="Tutorial">
<node CREATED="1354018289081" ID="ID_1945588195" MODIFIED="1354018293366" POSITION="right" TEXT="Getting started">
<node CREATED="1354018658946" ID="ID_1928026203" MODIFIED="1354018681586" TEXT="installation"/>
<node CREATED="1354018682389" ID="ID_1438856433" MODIFIED="1354018684963" TEXT="virtualenv"/>
<node CREATED="1354018685268" ID="ID_992690829" MODIFIED="1354018704549" TEXT="eggs in development"/>
<node CREATED="1354018704828" ID="ID_471611617" MODIFIED="1354018720437" TEXT="most basic hello world"/>
<node CREATED="1354018720646" ID="ID_1092174650" MODIFIED="1354018730305" TEXT="configuration"/>
<node CREATED="1354018730511" ID="ID_1296024046" MODIFIED="1354018744584" TEXT="preparing database"/>
<node CREATED="1354018744845" ID="ID_685605152" MODIFIED="1354018750376" TEXT="development swebserver"/>
</node>
<node CREATED="1354018293793" ID="ID_1584535190" MODIFIED="1354018318308" POSITION="right" TEXT="basic building blocks">
<node CREATED="1354018757291" ID="ID_11724780" MODIFIED="1354018782322" TEXT="programming on high level of abstraction"/>
<node CREATED="1354018783244" ID="ID_1131058150" MODIFIED="1354018794481" TEXT="widgets"/>
<node CREATED="1354018794909" ID="ID_1778272639" MODIFIED="1354018812051" TEXT="slots, views, main window"/>
<node CREATED="1354018830050" ID="ID_1990235477" MODIFIED="1354018832161" TEXT="factories"/>
<node CREATED="1354018832424" ID="ID_1827508591" MODIFIED="1354018841207" TEXT="lyfecycle of UI elements"/>
</node>
<node CREATED="1354018318751" ID="ID_1053235313" MODIFIED="1354018328660" POSITION="right" TEXT="models with makeup">
<node CREATED="1359460004081" ID="ID_1886378408" MODIFIED="1359460012712" TEXT="models"/>
<node CREATED="1359460014614" ID="ID_422647139" MODIFIED="1359460017585" TEXT="persistence"/>
<node CREATED="1359460018083" ID="ID_197181524" MODIFIED="1359460028473" TEXT="fields &amp; events"/>
</node>
<node CREATED="1354018330864" ID="ID_1606378861" MODIFIED="1354018336326" POSITION="right" TEXT="user interface basics">
<node CREATED="1359460031760" ID="ID_163866019" MODIFIED="1359460052665" TEXT="structuring an app using widgets"/>
<node CREATED="1359460053832" ID="ID_1950607033" MODIFIED="1359460116117" TEXT="tying inputs up to fields/events"/>
</node>
<node CREATED="1359460118090" ID="ID_394368519" MODIFIED="1359460133581" POSITION="right" TEXT="interacting views">
<node CREATED="1359460136149" ID="ID_994221473" MODIFIED="1359460139224" TEXT="bookmarks"/>
<node CREATED="1359460139717" ID="ID_1124364069" MODIFIED="1359460144325" TEXT="transitions"/>
<node CREATED="1359460144742" ID="ID_432218984" MODIFIED="1359460152715" TEXT="actions"/>
<node CREATED="1359460153423" ID="ID_560227817" MODIFIED="1359460157123" TEXT="guards"/>
</node>
</node>
</map>

==> reahl-doc-3.0.0.tar.gz: reahl-doc-3.0.0/doc/Tutorial.mm <==
<map version="0.9.0">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node CREATED="1354018227940" ID="ID_486696790" MODIFIED="1354018280646" TEXT="Tutorial">
<node CREATED="1354018289081" ID="ID_1945588195" MODIFIED="1354018293366" POSITION="right" TEXT="Getting started">
<node CREATED="1354018658946" ID="ID_1928026203" MODIFIED="1354018681586" TEXT="installation"/>
<node CREATED="1354018682389" ID="ID_1438856433" MODIFIED="1354018684963" TEXT="virtualenv"/>
<node CREATED="1354018685268" ID="ID_992690829" MODIFIED="1354018704549" TEXT="eggs in development"/>
<node CREATED="1354018704828" ID="ID_471611617" MODIFIED="1354018720437" TEXT="most basic hello world"/>
<node CREATED="1354018720646" ID="ID_1092174650" MODIFIED="1354018730305" TEXT="configuration"/>
<node CREATED="1354018730511" ID="ID_1296024046" MODIFIED="1354018744584" TEXT="preparing database"/>
<node CREATED="1354018744845" ID="ID_685605152" MODIFIED="1354018750376" TEXT="development swebserver"/>
</node>
<node CREATED="1354018293793" ID="ID_1584535190" MODIFIED="1354018318308" POSITION="right" TEXT="basic building blocks">
<node CREATED="1354018757291" ID="ID_11724780" MODIFIED="1354018782322" TEXT="programming on high level of abstraction"/>
<node CREATED="1354018783244" ID="ID_1131058150" MODIFIED="1354018794481" TEXT="widgets"/>
<node CREATED="1354018794909" ID="ID_1778272639" MODIFIED="1354018812051" TEXT="slots, views, page"/>
<node CREATED="1354018830050" ID="ID_1990235477" MODIFIED="1354018832161" TEXT="factories"/>
<node CREATED="1354018832424" ID="ID_1827508591" MODIFIED="1354018841207" TEXT="lyfecycle of UI elements"/>
</node>
<node CREATED="1354018318751" ID="ID_1053235313" MODIFIED="1354018328660" POSITION="right" TEXT="models with makeup">
<node CREATED="1359460004081" ID="ID_1886378408" MODIFIED="1359460012712" TEXT="models"/>
<node CREATED="1359460014614" ID="ID_422647139" MODIFIED="1359460017585" TEXT="persistence"/>
<node CREATED="1359460018083" ID="ID_197181524" MODIFIED="1359460028473" TEXT="fields &amp; events"/>
</node>
<node CREATED="1354018330864" ID="ID_1606378861" MODIFIED="1354018336326" POSITION="right" TEXT="user interface basics">
<node CREATED="1359460031760" ID="ID_163866019" MODIFIED="1359460052665" TEXT="structuring an app using widgets"/>
<node CREATED="1359460053832" ID="ID_1950607033" MODIFIED="1359460116117" TEXT="tying inputs up to fields/events"/>
</node>
<node CREATED="1359460118090" ID="ID_394368519" MODIFIED="1359460133581" POSITION="right" TEXT="interacting views">
<node CREATED="1359460136149" ID="ID_994221473" MODIFIED="1359460139224" TEXT="bookmarks"/>
<node CREATED="1359460139717" ID="ID_1124364069" MODIFIED="1359460144325" TEXT="transitions"/>
<node CREATED="1359460144742" ID="ID_432218984" MODIFIED="1359460152715" TEXT="actions"/>
<node CREATED="1359460153423" ID="ID_560227817" MODIFIED="1359460157123" TEXT="guards"/>
</node>
</node>
</map>
